@@ -65,7 +65,7 @@ class NumpyReader:
 
         self.count = self.headers["count"].sum()
         if self.count == 0:
-            raise ValueError("No embeddings found in folder {}".format(embeddings_folder))
+            raise ValueError(f"No embeddings found in folder {embeddings_folder}")
         self.dimension = int(self.headers.iloc[0]["dimension"])
         self.byte_per_item = self.headers.iloc[0]["byte_per_item"]
         self.dtype = self.headers.iloc[0]["dtype"]
@@ -81,7 +81,7 @@ class NumpyReader:
             batch_size = end - start
 
         if max_piece_size is None:
-            max_piece_size = max(int(50 * 10 ** 6 / (self.byte_per_item)), 1)
+            max_piece_size = max(int(50 * 10**6 / (self.byte_per_item)), 1)
         if parallel_pieces is None:
             parallel_pieces = max(math.ceil(batch_size / max_piece_size), 10)
 
@@ -126,7 +126,7 @@ class NumpyReader:
             for piece in (Piece(*parts) for parts in zip(*[pieces[col] for col in cols])):
                 if stopped:
                     break
-                semaphore.acquire()
+                semaphore.acquire()  # pylint: disable=consider-using-with
                 yield piece
 
         batch = None
